==> flutter_catalogue_widgets-0.0.6.tar.gz: lib/custom-materialChip.dart <==
/*
Widget Name:
- Material Chip

Description:
- Chips are compact elements that represent an input, attribute, or action.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-materialChip.dart';

Usage:
- Defining the callback and Material Chip objects
  MaterialChipData chipdata = new MaterialChipData(
      labelText: 'Books',
      deleteMsg: "deleted",
      shapeBorder: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(5),
          side: BorderSide(color: Colors.orange, width: 2)),
      selectedbgColor: Colors.orange,
      labelColor: Colors.white,
      bgColor: Colors.grey,
      checkmarkColor: Colors.orange);
  onclickChip(int nIndex, String sText) {
    print(nIndex);
    print(sText);
  }

- Widget call

            customChipWidget(
              data: chipdata,
              callback: onclickChip,

            ),

Author:
Satyabrat Padhy
*/

import "package:flutter/material.dart";
import 'theme.dart';
import 'consts.dart' as constants;
import 'widget-classesUsed.dart';

class customChipWidget extends StatefulWidget {
  final MaterialChipData data;
  final void Function(int, String) callback;
  final void Function(int, String) onDelete;

  customChipWidget({
    @required this.data,
    @required this.callback,
    @required this.onDelete,
  });
  @override
  _ChipState createState() => new _ChipState();
}

class _ChipState extends State<customChipWidget> {
  bool isChipSelected = false;

  @override
  Widget build(BuildContext context) {
    return InputChip(
      showCheckmark: true,
      checkmarkColor: widget.data.checkmarkColor != null
          ? widget.data.checkmarkColor
          : MediumGreyThemeData().hintColor,
      selected: isChipSelected,
      shape: widget.data.shapeBorder != null
          ? widget.data.shapeBorder
          : StadiumBorder(
          side: BorderSide(
              width: constants.heightTwo,
              color: MediumGreyThemeData().backgroundColor)),
      label: Text(
        (widget.data.labelText != null)
            ? widget.data.labelText
            : constants.chipLabel,
        style: TextStyle(
            color: widget.data.labelColor != null
                ? widget.data.labelColor
                : MediumGreyThemeData().accentIconTheme.color,
            fontSize: constants.fontLarger),
        overflow: TextOverflow.ellipsis,
      ),
      pressElevation: constants.heightFive,
      selectedColor: widget.data.selectedbgColor != null
          ? widget.data.selectedbgColor
          : MediumGreyThemeData().tabBarTheme.unselectedLabelColor,
      labelPadding: EdgeInsets.symmetric(horizontal: constants.heightTwenty),
      deleteIcon: Icon(Icons.close),
      deleteIconColor: MediumGreyThemeData().accentIconTheme.color,
      isEnabled: true,
      clipBehavior: Clip.antiAlias,
      backgroundColor: widget.data.bgColor != null
          ? widget.data.bgColor
          : MediumGreyThemeData().primaryColor,
      deleteButtonTooltipMessage: (widget.data.tooltipMsg != null)
          ? widget.data.tooltipMsg
          : constants.chipTooltipMessage,
      onPressed: () {
        setState(() {
          isChipSelected = true;
        });
        widget.callback(constants.intOne, widget.data.labelText);
      },
      materialTapTargetSize: MaterialTapTargetSize.padded,
      tooltip: (widget.data.deleteMsg != null)
          ? widget.data.deleteMsg
          : constants.chipDeleteMessage,
      onDeleted: () {
        setState(() {
          isChipSelected = false;
        });
        widget.onDelete(constants.intOne, widget.data.deleteMsg);
      },
    );
  }
}

==> flutter_catalogue_widgets-0.0.14.tar.gz: lib/custom-materialChip.dart <==
/*
Widget Name:
- Material Chip

Description:
- Chips are compact elements that represent an input, attribute, or action.

Imports:
import 'package:flutter_widgets_library/utils/widget-classesUsed.dart';
import 'custom-materialChip.dart';

Usage:
- Defining the callback and Material Chip objects
  MaterialChipData chipdata = new MaterialChipData(
      labelText: 'Books',
      deleteMsg: "deleted",
      shapeBorder: RoundedRectangleBorder(
          borderRadius: BorderRadius.circular(5),
          side: BorderSide(color: Colors.orange, width: 2)),
      selectedbgColor: Colors.orange,
      labelColor: Colors.white,
      bgColor: Colors.grey,
      checkmarkColor: Colors.orange);
  onclickChip(int nIndex, String sText) {
    print(nIndex);
    print(sText);
  }

- Widget call

            CustomChipWidget(
              data: chipdata,
              callback: onclickChip,

            ),

Author:
Satyabrat Padhy
*/

import "package:flutter/material.dart";
import 'theme.dart';
import 'consts.dart' as constants;
import 'widget-classesUsed.dart';

class CustomChipWidget extends StatefulWidget {
  final MaterialChipData data;
  final void Function(int, String) callback;
  final void Function(int, String) onDelete;

  CustomChipWidget({
    @required this.data,
    @required this.callback,
    @required this.onDelete,
  });
  @override
  _ChipState createState() => new _ChipState();
}

class _ChipState extends State<CustomChipWidget> {
  bool isChipSelected = false;

  @override
  Widget build(BuildContext context) {
    return InputChip(
      showCheckmark: true,
      checkmarkColor: widget.data.checkmarkColor != null
          ? widget.data.checkmarkColor
          : mediumGreyThemeData().hintColor,
      selected: isChipSelected,
      shape: widget.data.shapeBorder != null
          ? widget.data.shapeBorder
          : StadiumBorder(
          side: BorderSide(
              width: constants.heightTwo,
              color: mediumGreyThemeData().backgroundColor)),
      label: Text(
        (widget.data.labelText != null)
            ? widget.data.labelText
            : constants.chipLabel,
        style: TextStyle(
            color: widget.data.labelColor != null
                ? widget.data.labelColor
                : mediumGreyThemeData().accentIconTheme.color,
            fontSize: constants.fontLarger),
        overflow: TextOverflow.ellipsis,
      ),
      pressElevation: constants.heightFive,
      selectedColor: widget.data.selectedbgColor != null
          ? widget.data.selectedbgColor
          : mediumGreyThemeData().tabBarTheme.unselectedLabelColor,
      labelPadding: EdgeInsets.symmetric(horizontal: constants.heightTwenty),
      deleteIcon: Icon(Icons.close),
      deleteIconColor: mediumGreyThemeData().accentIconTheme.color,
      isEnabled: true,
      clipBehavior: Clip.antiAlias,
      backgroundColor: widget.data.bgColor != null
          ? widget.data.bgColor
          : mediumGreyThemeData().primaryColor,
      deleteButtonTooltipMessage: (widget.data.tooltipMsg != null)
          ? widget.data.tooltipMsg
          : constants.chipTooltipMessage,
      onPressed: () {
        setState(() {
          isChipSelected = true;
        });
        widget.callback(constants.intOne, widget.data.labelText);
      },
      materialTapTargetSize: MaterialTapTargetSize.padded,
      tooltip: (widget.data.deleteMsg != null)
          ? widget.data.deleteMsg
          : constants.chipDeleteMessage,
      onDeleted: () {
        setState(() {
          isChipSelected = false;
        });
        widget.onDelete(constants.intOne, widget.data.deleteMsg);
      },
    );
  }
}
